# Tiros

Tiros is a new AWS service for analysis of AWS networks.
See [the Wiki](https://github.com/awslabs/BETA-tiros/wiki) for an overview and detailed documentation.

This repo contains the following:

- The code for the tiros pip package
- Example CloudFormation templates
- Example Lambda function code written in Python

## Important

Tiros is a Beta service of AWS, and is subject to the AWS terms of service.
